@@ -1,5 +1,3 @@
-from dataclasses import dataclass
-
 from origo.config import Config
 
 
@@ -7,10 +5,14 @@ class TokenProviderNotInitialized(Exception):
     pass
 
 
-@dataclass
 class TokenProvider:
     config: Config
 
+    # TODO: Annotate the class with `@dataclass` and remove this once support
+    # for Python 3.6 is dropped.
+    def __init__(self, config: Config):
+        self.config = config
+
     def new_token(self):
         raise NotImplementedError
 
