@@ -12,8 +12,8 @@ ORIGO_CONFIG["dev"] = {
     "client_id": None,
     "client_secret": None,
     "cacheCredentials": False,
+    "dataExporterUrl": "https://api.data-dev.oslo.systems/data-exporter",
     "datasetUrl": "https://api.data-dev.oslo.systems/metadata/datasets",
-    "downloadUrl": "https://api.data-dev.oslo.systems/data-exporter",
     "elasticsearchQueryUrl": "https://api.data-dev.oslo.systems/elasticsearch-queries",
     "eventCollectorUrl": "https://api.data-dev.oslo.systems/event-collector",
     "keycloakRealm": "api-catalog",
@@ -30,8 +30,8 @@ ORIGO_CONFIG["prod"] = {
     "client_id": None,
     "client_secret": None,
     "cacheCredentials": True,
+    "dataExporterUrl": "https://api.data.oslo.systems/data-exporter",
     "datasetUrl": "https://api.data.oslo.systems/metadata/datasets",
-    "downloadUrl": "https://api.data.oslo.systems/data-exporter",
     "elasticsearchQueryUrl": "https://api.data.oslo.systems/elasticsearch-queries",
     "eventCollectorUrl": "https://api.data.oslo.systems/event-collector",
     "keycloakRealm": "api-catalog",
